@@ -24,11 +24,14 @@
 
 #include <kcmdlineargs.h>
 #include <kconfig.h>
+
+#ifdef HAVE_ARTS_SUPPORT
 #include <kcrash.h>
 #include <kglobal.h>
 #include <kstandarddirs.h>
-
+#include <arts/artsflow.h>
 #include <artsc/artsc.h> // for arts_init()
+#endif /* HAVE_ARTS_SUPPORT */
 
 #include "libkwave/Parser.h"
 
@@ -62,8 +65,10 @@ KwaveApp::KwaveApp()
     m_topwidget_list.setAutoDelete(false);
     readConfig();
 
+#ifdef HAVE_ARTS_SUPPORT
     // initialize the aRts daemon, start him if necessary
     initArts();
+#endif /* HAVE_ARTS_SUPPORT */
 
     // load the list of plugins
     PluginManager::findPlugins();
@@ -277,6 +282,7 @@ KwaveApp::~KwaveApp()
 }
 
 //***************************************************************************
+#ifdef HAVE_ARTS_SUPPORT
 void KwaveApp::initArts()
 {
     arts_init();
@@ -304,6 +310,7 @@ void KwaveApp::initArts()
 	} while (time < 6 && !Arts::Dispatcher::the());
     }
 }
+#endif /* HAVE_ARTS_SUPPORT */
 
 //***************************************************************************
 #include "KwaveApp.moc"
