@@ -30,7 +30,7 @@
 
 #include "mt/SignalProxy.h"
 
-#include "libkwave/ArtsMultiPlaybackSink.h"
+#include "libkwave/KwaveMultiPlaybackSink.h"
 #include "libkwave/LineParser.h"
 #include "libkwave/FileLoader.h"
 #include "libkwave/KwavePlugin.h"
@@ -533,49 +533,8 @@ SampleWriter *PluginManager::openSampleWriter(unsigned int track,
 }
 
 //***************************************************************************
-void PluginManager::openMultiTrackReader(MultiTrackReader &readers,
-    const QMemArray<unsigned int> &track_list,
-    unsigned int first, unsigned int last)
-{
-    SignalManager &manager = m_top_widget.signalManager();
-    manager.openMultiTrackReader(readers, track_list, first, last);
-}
-
-//***************************************************************************
-void PluginManager::openMultiTrackWriter(MultiTrackWriter &writers,
-    const QMemArray<unsigned int> &track_list, InsertMode mode,
-    unsigned int left, unsigned int right)
-{
-    SignalManager &manager = m_top_widget.signalManager();
-    manager.openMultiTrackWriter(writers, track_list, mode, left, right);
-}
-
-//***************************************************************************
-void PluginManager::openMultiTrackWriter(MultiTrackWriter &writers,
-                                         InsertMode mode)
-{
-    SignalManager &manager = m_top_widget.signalManager();
-    QMemArray<unsigned int> tracks = manager.selectedTracks();
-    unsigned int left = 0;
-    unsigned int right = 0;
-
-    if (signalLength()) {
-	// default if signal is present: current selection
-	left  = selectionStart();
-	right = selectionEnd();
-	if (left == right) {
-	    // if no selection: whole signal
-	    left  = 0;
-	    right = signalLength();
-	}
-    }
-
-    openMultiTrackWriter(writers, tracks, mode, left, right);
-}
-
-//***************************************************************************
-ArtsMultiSink *PluginManager::openMultiTrackPlayback(unsigned int tracks,
-                                                     const QString *name)
+Kwave::SampleSink *PluginManager::openMultiTrackPlayback(
+    unsigned int tracks, const QString *name)
 {
     QString device_name;
 
@@ -601,10 +560,8 @@ ArtsMultiSink *PluginManager::openMultiTrackPlayback(unsigned int tracks,
     if (!device) return 0;
 
     // create the multi track playback sink
-    ArtsMultiSink *sink = new ArtsMultiPlaybackSink(tracks, device);
+    Kwave::SampleSink *sink = new Kwave::MultiPlaybackSink(tracks, device);
     Q_ASSERT(sink);
-    if (!sink) return 0;
-
     return sink;
 }
 
