@@ -25,12 +25,9 @@
 #include <qptrvector.h>
 #include <qmap.h>
 
-#include <arts/artsflow.h>
-
 #include "mt/SignalProxy.h"
 #include "libkwave/InsertMode.h"
 
-class ArtsMultiSink;
 class FileInfo;
 class KwavePlugin;
 class PlaybackController;
@@ -43,6 +40,7 @@ class TopWidget;
 class UndoAction;
 class MultiTrackReader;
 class MultiTrackWriter;
+namespace Kwave { class SampleSink; }
 
 /**
  * Manages the loading, initializing, starting, running and closing
@@ -149,25 +147,6 @@ public:
     /** Returns a reference to our toplevel widget */
     inline TopWidget &topWidget() { return m_top_widget; };
 
-    /**
-     * Returns a set of opened SampleReader objects for reading from
-     * multiple tracks. The list of tracks may contain indices of tracks
-     * in any order and even duplicate entries are allowed. One useful
-     * application is passing the output of selectedTracks() in order
-     * to read from only from selected tracks.
-     * @param readers reference to the MultiTrackReader to be filled.
-     * @note the returned vector has set "autoDelete" to true, so you
-     *       don't have to care about cleaning up
-     * @param track_list array of indices of tracks for reading
-     * @param first index of the first sample
-     * @param last index of the last sample
-     * @see SampleReader
-     * @see selectedTracks()
-     */
-    void openMultiTrackReader(MultiTrackReader &readers,
-	const QMemArray<unsigned int> &track_list,
-	unsigned int first, unsigned int last);
-
     /**
      * Opens an input stream for a track, starting at a specified sample
      * position. Also handles undo information.
@@ -183,39 +162,14 @@ public:
 	unsigned int left = 0, unsigned int right = 0);
 
     /**
-     * Opens a set of SampleWriters and internally handles the creation of
-     * needed undo information. This is useful for multi-channel operations.
-     * @param writers reference to a vector that receives all writers.
-     * @param track_list list of indices of tracks to be modified.
-     * @param mode specifies where and how to insert
-     * @param left start of the input (only useful in insert and
-     *             overwrite mode)
-     * @param right end of the input (only useful with overwrite mode)
-     * @see InsertMode
-     */
-    void openMultiTrackWriter(MultiTrackWriter &writers,
-	const QMemArray<unsigned int> &track_list, InsertMode mode,
-	unsigned int left, unsigned int right);
-
-    /**
-     * Opens a set of SampleWriters using the currently selected list of
-     * tracks and the current selection. If nothing is selected, the whole
-     * signal will be selected.
-     * @param writers reference to a vector that receives all writers.
-     * @param mode specifies where and how to insert
-     */
-    void openMultiTrackWriter(MultiTrackWriter &writers,
-                              InsertMode mode);
-
-    /**
-     * Opens a set of SampleWriters for playback purposes.
+     * Opens a Kwave::MultiTrackSink for playback purposes.
      * @param tracks number of tracks
      * @param name of the device, optional. If not given, the default
      *        playback device is used
      * @return a multitrack aRts sink that receives the playback stream
      */
-    ArtsMultiSink *openMultiTrackPlayback(unsigned int tracks,
-                                          const QString *name = 0);
+    Kwave::SampleSink *openMultiTrackPlayback(unsigned int tracks,
+                                              const QString *name = 0);
 
     /**
      * Returns a reference to the current playback controller. This is
@@ -237,11 +191,6 @@ public:
      */
     static void findPlugins();
 
-    /** Returns a reference to the global aRts dispatcher */
-    inline Arts::Dispatcher *artsDispatcher() {
-	return Arts::Dispatcher::the();
-    };
-
     /**
      * Registers a PlaybackDeviceFactory
      */
