@@ -192,11 +192,9 @@ int SignalManager::loadFile(const KURL &url)
 	if (track < tracks) break;
 
 	// create the multitrack writer as destination
-	MultiTrackWriter writers;
-
 	// if length was zero -> append mode / decode a stream ?
 	InsertMode mode = (streaming) ? Append : Overwrite;
-	openMultiTrackWriter(writers, allTracks(), mode, 0,
+	MultiTrackWriter writers(*this, allTracks(), mode, 0,
 	    (length) ? length-1 : 0);
 
 	// try to calculate the resulting length, but if this is
@@ -352,12 +350,9 @@ int SignalManager::save(const KURL &url, bool selection)
 	QString filename = url.path();
 	QFile dst(filename);
 
-	MultiTrackReader src;
-	if (selection) {
-	    openMultiTrackReader(src, selectedTracks(), ofs, ofs+len-1);
-	} else {
-	    openMultiTrackReader(src, allTracks(), ofs, ofs+len-1);
-	}
+	MultiTrackReader src(*this,
+	    (selection) ? selectedTracks() : allTracks(),
+	    ofs, ofs+len-1);
 
 	// update the file information
 	m_file_info.setLength(len);
@@ -614,42 +609,6 @@ SampleWriter *SignalManager::openSampleWriter(unsigned int track,
     return writer;
 }
 
-//***************************************************************************
-void SignalManager::openMultiTrackReader(MultiTrackReader &readers,
-    const QMemArray<unsigned int> &track_list,
-    unsigned int first, unsigned int last)
-{
-    m_signal.openMultiTrackReader(readers, track_list, first, last);
-}
-
-//***************************************************************************
-void SignalManager::openMultiTrackWriter(MultiTrackWriter &writers,
-    const QMemArray<unsigned int> &track_list, InsertMode mode,
-    unsigned int left, unsigned int right)
-{
-    UndoTransactionGuard guard(*this, 0);
-    unsigned int count = track_list.count();
-    unsigned int track;
-    writers.clear();
-    writers.resize(count);
-
-    for (unsigned int i=0; i < count; i++) {
-	track = track_list[i];
-	// NOTE: this function is *nearly* identical to the one in the
-	//       Signal class, except for undo support
-	SampleWriter *s = openSampleWriter(track, mode, left, right, true);
-	if (s) {
-	    writers.insert(i, s);
-	} else {
-	    // out of memory or aborted
-	    qDebug("Signal::openMultiTrackWriter: "\
-	          "out of memory or aborted");
-	    writers.clear();
-	    return;
-	}
-    }
-}
-
 //***************************************************************************
 bool SignalManager::executeCommand(const QString &command)
 {
@@ -758,25 +717,16 @@ void SignalManager::paste(ClipBoard &clipboard, unsigned int offset,
 	while (missing--) appendTrack();
     }
 
-    // open the clipboard as source
-    MultiTrackReader src;
-    clipboard.openMultiTrackReader(src);
-    if (src.isEmpty()) {
-	abortUndoTransaction();
-	return;
-    }
-
     // open a stream into the signal
-    MultiTrackWriter dst;
-    openMultiTrackWriter(dst, selectedTracks(), Insert,
+    MultiTrackWriter dst(*this, selectedTracks(), Insert,
                          offset, offset+clipboard.length()-1);
-    if (dst.isEmpty()) {
+    if (dst.tracks() != selectedTracks().count()) {
 	abortUndoTransaction();
 	return;
     }
 
     // transfer the content
-    dst << src;
+    clipboard.paste(dst);
 
     // set the selection to the inserted range
     selectRange(offset, clipboard.length());
