@@ -251,41 +251,6 @@ public:
 	return m_signal.openSampleReader(track, left, right);
     };
 
-    /**
-     * Returns a set of opened SampleReader objects for reading from
-     * multiple tracks. The list of tracks may contain indices of tracks
-     * in any order and even duplicate entries are allowed. One useful
-     * application is passing the output of selectedTracks() in order
-     * to read from only from selected tracks.
-     * @param readers reference to the MultiTrackReader to be filled.
-     * @note the returned vector has set "autoDelete" to true, so you
-     *       don't have to care about cleaning up
-     * @param track_list array of indices of tracks for reading
-     * @param first index of the first sample
-     * @param last index of the last sample
-     * @see SampleReader
-     * @see selectedTracks()
-     * @see Signal::openMultiTrackWriter
-     */
-    void openMultiTrackReader(MultiTrackReader &readers,
-	const QMemArray<unsigned int> &track_list,
-	unsigned int first, unsigned int last);
-
-    /**
-     * Opens a set of SampleWriters and internally handles the creation of
-     * needed undo information. This is useful for multi-channel operations.
-     * @param writers reference to a vector that receives all writers.
-     * @param track_list list of indices of tracks to be modified.
-     * @param mode specifies where and how to insert
-     * @param left start of the input (only useful in insert and
-     *             overwrite mode)
-     * @param right end of the input (only useful with overwrite mode)
-     * @see Signal::openMultiTrackWriter
-     */
-    void openMultiTrackWriter(MultiTrackWriter &writers,
-	const QMemArray<unsigned int> &track_list, InsertMode mode,
-	unsigned int left, unsigned int right);
-
     /** Returns true if undo/redo is currently enabled */
     inline bool undoEnabled() { return m_undo_enabled; };
 
