@@ -2345,13 +2345,12 @@ void SignalWidget::startDragging()
     Q_ASSERT(d);
     if (!d) return;
 
-    MultiTrackReader src;
     const unsigned int first = m_signal_manager.selection().first();
     const unsigned int last  = m_signal_manager.selection().last();
     const double       rate  = m_signal_manager.rate();
     const unsigned int bits  = m_signal_manager.bits();
 
-    m_signal_manager.openMultiTrackReader(src,
+    MultiTrackReader src(m_signal_manager,
 	m_signal_manager.selectedTracks(), first, last);
 
     // create the file info
@@ -2359,7 +2358,7 @@ void SignalWidget::startDragging()
     info.setLength(last - first + 1);
     info.setRate(rate);
     info.setBits(bits);
-    info.setTracks(src.count());
+    info.setTracks(src.tracks());
 
     if (!d->encode(this, src, info)) {
 	delete d;
@@ -2408,27 +2407,18 @@ void SignalWidget::dropEvent(QDropEvent* event)
 {
     if (KwaveDrag::canDecode(event)) {
 	UndoTransactionGuard undo(m_signal_manager, i18n("drag and drop"));
-	MultiTrackReader src;
-	MultiTrackWriter dst;
 	Signal sig;
+	InhibitRepaintGuard inhibit(*this);
+	unsigned int pos = m_offset + pixels2samples(event->pos().x());
+	unsigned int len = 0;
 
-	if (KwaveDrag::decode(this, event, sig)) {
-	    InhibitRepaintGuard inhibit(*this);
-	    unsigned int pos = m_offset + pixels2samples(event->pos().x());
-	    unsigned int len = sig.length();
-
+	/** @todo add a converter if rate does not match */
+	if ((len = KwaveDrag::decode(this, event, m_signal_manager, pos))) {
 	    /**
 	     * @todo after the drop operation: enter the new file info into
 	     * the signal manager if our own file was empty
 	     */
 
-	    sig.openMultiTrackReader(src, sig.allTracks(), 0, len-1);
-	    m_signal_manager.openMultiTrackWriter(dst,
-		m_signal_manager.selectedTracks(), Insert,
-		pos, pos+len-1);
-	    /** @todo add a converter if rate does not match */
-	    dst << src;
-
 	    // set selection to the new area where the drop was done
 	    selectRange(pos, len);
 	} else {
