@@ -21,13 +21,12 @@
 #include "config.h"
 #include <qdragobject.h>
 #include <qlabel.h>
+#include <qpoint.h>
 #include <qptrlist.h>
 #include <qtimer.h>
 #include <qpainter.h>
 #include <qwidget.h>
 
-#include "libkwave/LabelList.h"
-
 #include "PlaybackController.h"
 #include "SignalManager.h"
 
@@ -104,12 +103,6 @@ public:
     void newSignal(unsigned int samples, double rate,
                    unsigned int bits, unsigned int tracks);
 
-    /** @todo (re)implementation */
-    int saveFile(const KURL &url, bool selection = false);
-
-    /** @todo (re)implementation */
-    void saveBlocks (int);
-
     /**
      * Closes the current signal
      */
@@ -141,9 +134,7 @@ public:
      */
     bool isInSelection(int x);
 
-//    void addLabelType (LabelType *);
-//    void addLabelType (const char *);
-
+    /** Executes a Kwave text command */
     bool executeCommand(const QString &command);
 
     /**
@@ -158,41 +149,6 @@ public:
     /** Returns the playback controller */
     PlaybackController &playbackController();
 
-    /**
-     * add a new label
-     * @param pos position of the label [samples]
-     */
-    void addLabel(unsigned int pos);
-
-    /**
-     * add a new label, without undo
-     * @param pos position of the label [samples]
-     * @param name the name of the label
-     * @return pointer to the new created label
-     */
-    Label *addLabel(unsigned int pos, const QString &name);
-
-    /**
-     * delete an existing label
-     * @param index the index of the label [0...N-1]
-     * @param with_undo if true, create undo info
-     */
-    void deleteLabel(int index, bool with_undo);
-
-    /**
-     * find a label by it's index
-     * @param index the index of the label [0...N-1]
-     * @return pointer to the label or null pointer if not found
-     */
-    Label *labelAtIndex(int index);
-
-    /**
-     * Returns the index of a label, counting from zero
-     * @param label pointer to a Label
-     * @return index [0...N-1] or -1 if label is a null pointer
-     */
-    int labelIndex(const Label *label) const;
-
 public slots:
 
     /**
@@ -284,21 +240,13 @@ protected:
     /** @see Qt XDND documentation */
     virtual void dragMoveEvent(QDragMoveEvent *event);
 
-protected:
-
     friend class UndoModifyLabelAction;
 
-    /**
-     * returns the label at a given exact position
-     * @param pos position of the label [samples]
-     * @return the label at the position or null if not found
-     */
-    Label *findLabel(unsigned int pos) const;
+protected slots:
 
     /** Refreshes the layer with the markers */
     void refreshMarkersLayer();
 
-protected slots:
 
     /**
      * Allows repainting of the display by decrementing the repaint
@@ -394,6 +342,11 @@ private slots:
      */
     void timedRepaint();
 
+    /** Hide the current position marker */
+    void hidePosition() {
+	showPosition(0, 0, 0, QPoint(-1,-1));
+    };
+
     /** context menu: "edit/undo" */
     void contextMenuEditUndo()   { forwardCommand("undo()"); };
 
@@ -412,6 +365,21 @@ private slots:
     /** context menu: "save selection" */
     void contextMenuSaveSelection()  { forwardCommand("saveselect()"); };
 
+    /** context menu: "expand to labels" */
+    void contextMenuSelectionExpandToLabels()  {
+	forwardCommand("expandtolabel()");
+    };
+
+    /** context menu: "select next labels" */
+    void contextMenuSelectionNextLabels()  {
+	forwardCommand("selectnextlabels()");
+    };
+
+    /** context menu: "select previous labels" */
+    void contextMenuSelectionPrevLabels()  {
+	forwardCommand("selectprevlabels()");
+    };
+
     /** context menu: "label / new" */
     void contextMenuLabelNew();
 
@@ -671,6 +639,22 @@ private:
     void showPosition(const QString &text, unsigned int pos, double ms,
                       const QPoint &mouse);
 
+    /** Shortcut for accessing the label list @note can be modified */
+    inline LabelList &labels() {
+	return m_signal_manager.fileInfo().labels();
+    };
+
+    /** Shortcut for accessing the label list @note cannot be modified */
+    inline const LabelList &labels() const {
+	return m_signal_manager.fileInfo().labels();
+    };
+
+    /**
+     * add a new label
+     * @param pos position of the label [samples]
+     */
+    void addLabel(unsigned int pos);
+
 private:
 
     /** Pixmaps for buffering each layer */
@@ -732,9 +716,6 @@ private:
     /** list of track pixmaps */
     QPtrList<TrackPixmap> m_track_pixmaps;
 
-    /** list of labels */
-    LabelList m_labels;
-
     /** pixmap for avoiding flicker */
     QPixmap *m_pixmap;
 
