@@ -113,7 +113,7 @@ TopWidget::ZoomListPrivate::ZoomListPrivate()
     append("10 min", 10L*60L*1000L);
     append("30 min", 30L*60L*1000L);
     append("60 min", 60L*60L*1000L);
-};
+}
 
 //***************************************************************************
 void TopWidget::ZoomListPrivate::append(const char *text, unsigned int ms)
@@ -486,23 +486,6 @@ TopWidget::TopWidget(KwaveApp &main_app)
     updateMenu();
     updateRecentFiles();
 
-    // check if the aRts dispatcher is functional. if not, we better
-    // should exit now, as most of the plugins would not work
-    if (!m_plugin_manager->artsDispatcher()) {
-	qWarning("no aRts dispatcher found -> exit !!!");
-	KMessageBox::error(this, i18n(
-	    "<b>Sorry, but since version 0.6.2 you need a running "\
-	    "aRts sound server for using kwave.</b><br>"\
-	    "You can setup aRts through the KDE control panel. "\
-	    "For more information, please refer to "\
-	    "the documentation shipped with KDE or "\
-	    "<a href=http://www.arts-project.org>"\
-	    "http://www.arts-project.org</a>."
-	));
-	qApp->exit();
-	return;
-    }
-
     // now we are initialized, load all plugins now
     statusBar()->message(i18n("Loading plugins..."));
     m_plugin_manager->loadAllPlugins();
@@ -540,8 +523,7 @@ bool TopWidget::isOK()
     Q_ASSERT(m_zoomselect);
 
     return ( m_menu_manager && m_main_widget &&
-	m_plugin_manager && m_toolbar && m_zoomselect &&
-        (m_plugin_manager->artsDispatcher()) );
+	m_plugin_manager && m_toolbar && m_zoomselect);
 }
 
 //***************************************************************************
@@ -634,7 +616,7 @@ int TopWidget::executeCommand(const QString &line)
 	qDebug("TopWidget::executeCommand(): loading plugin '%s'",
 	       name.local8Bit().data());
 	qDebug("TopWidget::executeCommand(): with %d parameter(s)",
-		(params) ? params->count() : 0);
+		(params) ? (int)params->count() : (int)0);
 	Q_ASSERT(m_plugin_manager);
 	if (m_plugin_manager)
 	    result = m_plugin_manager->executePlugin(name, params);
