@@ -116,4 +116,7 @@ void MenuGroup::clear()
     }
 }
 
-/* end of libgui/MenuGroup.cpp */
+//***************************************************************************
+#include "MenuGroup.moc"
+//***************************************************************************
+//***************************************************************************
