@@ -29,6 +29,7 @@
 #include "libkwave/MultiTrackReader.h"
 #include "libkwave/MultiTrackWriter.h"
 #include "kwave/CodecManager.h"
+#include "kwave/SignalManager.h"
 
 // RFC 2361:
 #define WAVE_FORMAT_PCM "audio/vnd.wave" // ; codec=001"
@@ -75,8 +76,8 @@ bool KwaveDrag::canDecode(const QMimeSource* e)
 //***************************************************************************
 bool KwaveDrag::encode(QWidget *widget, MultiTrackReader &src, FileInfo &info)
 {
-    Q_ASSERT(src.count());
-    if (!src.count()) return false;
+    Q_ASSERT(src.tracks());
+    if (!src.tracks()) return false;
     Q_ASSERT(src[0]);
     if (!src[0]) return false;
 
@@ -97,40 +98,42 @@ bool KwaveDrag::encode(QWidget *widget, MultiTrackReader &src, FileInfo &info)
 }
 
 //***************************************************************************
-bool KwaveDrag::decode(QWidget *widget, const QMimeSource *e, Signal &sig)
+unsigned int KwaveDrag::decode(QWidget *widget, const QMimeSource *e,
+                               SignalManager &sig, unsigned int pos)
 {
     // try to find a suitable decoder
     Decoder *decoder = CodecManager::decoder(e);
     Q_ASSERT(decoder);
-    if (!decoder) return false;
+    if (!decoder) return 0;
 
     // decode, use the first format that matches
     int i;
     const char *format;
-    bool ok = false;
+    unsigned int decoded_length = 0;
 
     for (i=0; (format = e->format(i)); ++i) {
 	if (CodecManager::canDecode(format)) {
 	    QBuffer src(e->encodedData(format));
 
 	    // open the mime source and get header information
-	    ok = decoder->open(widget, src);
-	    if (!ok) break;
-	    FileInfo &info = decoder->info();
+	    bool ok = decoder->open(widget, src);
+	    if (!ok) continue;
+	    decoded_length = decoder->info().length();
+	    Q_ASSERT(decoded_length);
+	    if (!decoded_length) continue;
 
 	    // prepare the signal
-	    while (sig.tracks() < info.tracks())
-		sig.appendTrack(info.length());
-	    MultiTrackWriter dst;
-	    sig.openMultiTrackWriter(dst, sig.allTracks(), Overwrite,
-	                             0, sig.length()-1);
+	    unsigned int left  = pos;
+	    unsigned int right = left + decoded_length - 1;
+	    MultiTrackWriter dst(sig, sig.allTracks(), Insert,
+	                         left, right);
 
 	    ok = decoder->decode(widget, dst);
 	    break;
 	}
     }
     delete decoder;
-    return ok;
+    return decoded_length;
 }
 
 //***************************************************************************
