@@ -30,7 +30,7 @@ class QWidget;
 
 class FileInfo;
 class MultiTrackReader;
-class Signal;
+class SignalManager;
 
 /**
  * Simple class for drag & drop of wav data.
@@ -85,9 +85,10 @@ public:
      * @param widget the widget used for displaying error messages
      * @param e mime source
      * @param sig signal that receives the mime data
-     * @return true if successful, false if failed
+     * @return number of decoded samples if successful, zero if failed
      */
-    static bool decode(QWidget *widget, const QMimeSource *e, Signal &sig);
+    static unsigned int decode(QWidget *widget, const QMimeSource *e,
+                               SignalManager &sig, unsigned int pos);
 
 private:
 
