@@ -30,6 +30,46 @@ LabelList::~LabelList()
     clear();
 }
 
+/***************************************************************************/
+bool LabelList::equals(const LabelList &other) const
+{
+    // shortcut: both empty ?
+    if (isEmpty() && other.isEmpty()) return true;
+
+    // quick check: does the number of elements match?
+    if (count() != other.count()) return false;
+
+    LabelListIterator it_mine(*this);
+    LabelListIterator it_other(other);
+
+    for (; it_mine.current() && it_other.current(); ++it_mine, ++it_other) {
+	Label *mine  = it_mine.current();
+	Label *other = it_other.current();
+
+	if (mine->pos()  != other->pos())  return false;
+	if (mine->name() != other->name()) return false;
+    }
+
+    return true;
+}
+
+/***************************************************************************/
+void LabelList::copy(const LabelList &source)
+{
+    // throw away any old stuff
+    clear();
+
+    // always make a deep copy, copy all elements
+    LabelListIterator it(source);
+    for (; it.current(); ++it) {
+	Label *label = it.current();
+	Q_ASSERT(label);
+	Label *copy  = new Label(*label);
+	Q_ASSERT(copy);
+	if (copy) append(copy);
+    }
+}
+
 //***************************************************************************
 int LabelList::compareItems(QPtrCollection::Item a, QPtrCollection::Item b)
 {
