@@ -175,50 +175,6 @@ SampleReader *Signal::openSampleReader(unsigned int track,
     return (t) ? t->openSampleReader(left, right) : 0;
 }
 
-//***************************************************************************
-void Signal::openMultiTrackReader(MultiTrackReader &readers,
-    const QMemArray<unsigned int> &track_list,
-    unsigned int first, unsigned int last)
-{
-    unsigned int count = track_list.count();
-    unsigned int track;
-    readers.clear();
-    readers.resize(count);
-
-    for (unsigned int i=0; i < count; i++) {
-	track = track_list[i];
-	SampleReader *s = openSampleReader(track, first, last);
-	Q_ASSERT(s);
-	readers.insert(i, s);
-    }
-
-}
-
-//***************************************************************************
-void Signal::openMultiTrackWriter(MultiTrackWriter &writers,
-    const QMemArray<unsigned int> &track_list, InsertMode mode,
-    unsigned int left, unsigned int right)
-{
-    unsigned int count = track_list.count();
-    unsigned int track;
-    writers.clear();
-    writers.resize(count);
-
-    for (unsigned int i=0; i < count; i++) {
-	track = track_list[i];
-	SampleWriter *s = openSampleWriter(track, mode, left, right);
-	if (s) {
-	    writers.insert(i, s);
-	} else {
-	    // out of memory or aborted
-	    qDebug("Signal::openMultiTrackWriter: "\
-	          "out of memory or aborted");
-	    writers.clear();
-	    return;
-	}
-    }
-}
-
 //***************************************************************************
 const QMemArray<unsigned int> Signal::allTracks()
 {
