@@ -111,17 +111,6 @@ public:
                         unsigned int offset,
                         unsigned int count);
 
-    /**
-     * Inserts an array of samples into the stripe.
-     * @param samples array with the samples
-     * @param offset position within the stripe, relative to the start of
-     *        the stripe [0...length()-1]
-     * @param count number of samples in the array
-     * @return number of samples appended
-     */
-    unsigned int insert(const QMemArray<sample_t> &samples,
-                        unsigned int offset, unsigned int count);
-
     /**
      * Deletes a range of samples
      * @param offset index of the first sample, relative to the start of
@@ -163,36 +152,6 @@ public:
      */
     Stripe &operator << (const QMemArray<sample_t> &samples);
 
-signals:
-
-    /**
-     * Emitted if the stripe has grown. This implies a modification of
-     * the inserted data, so no extra sigSamplesModified is emitted.
-     * @param src source stripe of the signal (*this)
-     * @param offset position from which the data was inserted
-     * @param length number of samples inserted
-     * @see sigSamplesModified
-     */
-    void sigSamplesInserted(Stripe &src, unsigned int offset,
-                            unsigned int length);
-
-    /**
-     * Emitted if data has been removed from the stripe.
-     * @param src source stripe of the signal (*this)
-     * @param offset position from which the data was removed
-     * @param length number of samples deleted
-     */
-    void sigSamplesDeleted(Stripe &src, unsigned int offset,
-                           unsigned int length);
-
-    /**
-     * Emitted if some data within the stripe has been modified.
-     * @param offset position from which the data was modified
-     * @param length number of samples modified
-     */
-    void sigSamplesModified(unsigned int offset,
-                            unsigned int length);
-
 protected:
 
     /**
