@@ -53,8 +53,13 @@ Decoder *FlacDecoder::instance()
 }
 
 //***************************************************************************
+#if defined(FLAC_API_VERSION_1_1_2) || defined(FLAC_API_VERSION_1_1_1_OR_OLDER)
 ::FLAC__StreamDecoderReadStatus FlacDecoder::read_callback(
         FLAC__byte buffer[], unsigned int *bytes)
+#else
+::FLAC__StreamDecoderReadStatus FlacDecoder::read_callback(
+        FLAC__byte buffer[], size_t *bytes)
+#endif
 {
     Q_ASSERT(bytes);
     Q_ASSERT(m_source);
@@ -67,7 +72,7 @@ Decoder *FlacDecoder::instance()
     }
 
     // read into application buffer
-    unsigned long int len = *bytes;
+    Q_LONG len = *bytes;
     *bytes = m_source->readBlock((char*)(&(buffer[0])), len);
 
     if (!*bytes) return FLAC__STREAM_DECODER_READ_STATUS_END_OF_STREAM;
@@ -158,7 +163,7 @@ void FlacDecoder::parseVorbisComments(
         const FLAC::Metadata::VorbisComment &vorbis_comments)
 {
     // first of all: the vendor string, specifying the software
-#ifdef FLAC_API_VERSION_1_1_1_OR_OLDER
+#if defined(FLAC_API_VERSION_1_1_1_OR_OLDER)
     if (vorbis_comments.get_vendor_string().is_valid()) {
 	const FLAC::Metadata::VorbisComment::Entry &entry =
 		vorbis_comments.get_vendor_string();
@@ -169,13 +174,15 @@ void FlacDecoder::parseVorbisComments(
 	m_info.set(INF_SOFTWARE, s);
 	qDebug("Encoded by: '%s'\n\n", s.local8Bit().data());
     }
-#else
+#elif defined(FLAC_API_VERSION_1_1_2) || defined(FLAC_API_VERSION_1_1_3)
     QString vendor = QString::fromUtf8(reinterpret_cast<const char *>(
 	vorbis_comments.get_vendor_string()));
     if (vendor.length()) {
 	m_info.set(INF_SOFTWARE, vendor);
 	qDebug("Encoded by: '%s'\n\n", vendor.local8Bit().data());
     }
+#else
+    #error "no usable FLAC API found"
 #endif
 
     // parse all vorbis comments into Kwave file properties
@@ -275,17 +282,26 @@ bool FlacDecoder::open(QWidget *widget, QIODevice &src)
     set_metadata_respond_all();
 
     // initialize the stream
-    FLAC::Decoder::Stream::State state = init();
-    if (state >= FLAC__STREAM_DECODER_END_OF_STREAM) {
-	KMessageBox::error(widget, i18n(
-	   "opening the FLAC bitstream failed."));
-	return false;
+#if defined(FLAC_API_VERSION_1_1_3)
+    FLAC__StreamDecoderInitStatus init_state = init();
+    if (init_state > FLAC__STREAM_DECODER_INIT_STATUS_OK) {
+        KMessageBox::error(widget, i18n(
+           "opening the FLAC bitstream failed."));
+        return false;
     }
+#else /* API v1.1.2 and older */
+    FLAC::Decoder::Stream::State init_state = init();
+    if (init_state >= FLAC__STREAM_DECODER_END_OF_STREAM) {
+        KMessageBox::error(widget, i18n(
+           "opening the FLAC bitstream failed."));
+        return false;
+    }
+#endif
 
     // read in all metadata
     process_until_end_of_metadata();
 
-    state = get_state();
+    FLAC::Decoder::Stream::State state = get_state();
     if (state >= FLAC__STREAM_DECODER_END_OF_STREAM) {
 	KMessageBox::error(widget, i18n(
 	   "error while parsing FLAC metadata. (%s)"),
