@@ -43,5 +43,7 @@ void MP3DecoderPlugin::load(QStringList &/* params */)
     if (m_decoder) CodecManager::registerDecoder(*m_decoder);
 }
 
-/***************************************************************************/
-/***************************************************************************/
+//***************************************************************************
+#include "MP3DecoderPlugin.moc"
+//***************************************************************************
+//***************************************************************************
