@@ -38,11 +38,14 @@
 
 #include "mt/ThreadsafeX11Guard.h"
 
-#include "libkwave/ArtsMultiPlaybackSink.h"
-#include "libkwave/ArtsMultiTrackSource.h"
-#include "libkwave/ArtsNativeMultiTrackFilter.h"
 #include "libkwave/Curve.h"
-#include "libkwave/CurveStreamAdapter_impl.h"
+#include "libkwave/CurveStreamAdapter.h"
+#include "libkwave/KwaveConnect.h"
+#include "libkwave/KwaveDelay.h"
+#include "libkwave/KwaveMul.h"
+#include "libkwave/KwaveMultiPlaybackSink.h"
+#include "libkwave/KwaveMultiTrackSource.h"
+#include "libkwave/KwaveOsc.h"
 #include "libkwave/KwavePlugin.h"
 #include "libkwave/Matrix.h"
 #include "libkwave/MultiTrackReader.h"
@@ -244,6 +247,56 @@ bool PlayBackPlugin::supportsDevice(const QString &name)
     return true;
 }
 
+//***************************************************************************
+PlayBackDevice *PlayBackPlugin::createDevice(playback_method_t method)
+{
+    bool searching = false;
+    do {
+	switch (method) {
+#ifdef HAVE_ARTS_SUPPORT
+	    case PLAYBACK_ARTS: {
+		ThreadsafeX11Guard x11_guard;
+
+		// if no mutex exists: make a new, parent is global app!
+		if (!g_arts_lock) g_arts_lock = new QMutex();
+		Q_ASSERT(g_arts_lock);
+
+		return new PlayBackArts(*g_arts_lock);
+	    }
+#endif /* HAVE_ARTS_SUPPORT */
+
+#ifdef HAVE_OSS_SUPPORT
+	    case PLAYBACK_OSS:
+		return new PlayBackOSS();
+#endif /* HAVE_OSS_SUPPORT */
+
+#ifdef HAVE_ALSA_SUPPORT
+	    case PLAYBACK_ALSA:
+		return new PlayBackALSA();
+#endif /* HAVE_ALSA_SUPPORT */
+
+	    default:
+		qDebug("unsupported playback method (%d)", (int)method);
+		if (!searching) {
+		    // start trying out all other methods
+		    searching = true;
+		    method = PLAYBACK_NONE;
+		    ++method;
+		    continue;
+		} else {
+		    // try next method
+		    ++method;
+		}
+		qDebug("unsupported playback method - trying next (%d)",
+		    (int)method);
+		if (method != PLAYBACK_INVALID) continue;
+	}
+	break;
+    } while (true);
+
+    return 0; // nothing found :-(
+}
+
 //***************************************************************************
 void PlayBackPlugin::setMethod(playback_method_t method)
 {
@@ -256,7 +309,6 @@ void PlayBackPlugin::setMethod(playback_method_t method)
     if ((method != m_playback_params.method) || !m_device) {
 	if (m_device) delete m_device;
 	m_device = 0;
-	bool searching = false;
 
 	// set hourglass cursor
 	QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
@@ -286,52 +338,7 @@ void PlayBackPlugin::setMethod(playback_method_t method)
 	    m_dialog->setDevice(m_playback_params.device);
 	}
 
-	do {
-	    switch (method) {
-#ifdef HAVE_ARTS_SUPPORT
-		case PLAYBACK_ARTS: {
-		    ThreadsafeX11Guard x11_guard;
-
-		    // if no mutex exists: make a new, parent is global app!
-		    if (!g_arts_lock) g_arts_lock = new QMutex();
-		    Q_ASSERT(g_arts_lock);
-
-		    m_device = new PlayBackArts(*g_arts_lock);
-		    break;
-		}
-#endif /* HAVE_ARTS_SUPPORT */
-
-#ifdef HAVE_OSS_SUPPORT
-		case PLAYBACK_OSS:
-		    m_device = new PlayBackOSS();
-		    Q_ASSERT(m_device);
-		    break;
-#endif /* HAVE_OSS_SUPPORT */
-
-#ifdef HAVE_ALSA_SUPPORT
-		case PLAYBACK_ALSA:
-		    m_device = new PlayBackALSA();
-		    Q_ASSERT(m_device);
-		    break;
-#endif /* HAVE_ALSA_SUPPORT */
-		default:
-		    qDebug("unsupported playback method (%d)", (int)method);
-		    if (!searching) {
-			// start trying out all other methods
-			searching = true;
-			method = PLAYBACK_NONE;
-			++method;
-			continue;
-		    } else {
-			// try next method
-			++method;
-		    }
-		    qDebug("unsupported playback method - trying next (%d)",
-		           (int)method);
-		    if (method != PLAYBACK_INVALID) continue;
-	    }
-	    break;
-	} while (true);
+	m_device = createDevice(method);
     }
     Q_ASSERT(m_device);
 
@@ -391,14 +398,17 @@ PlayBackDevice *PlayBackPlugin::openDevice(const QString &name,
 {
     QString device_name = name;
     PlayBackParam params;
+    PlayBackDevice *device = 0;
 
 //     qDebug("PlayBackPlugin::openDevice('%s',params)",name.data());
 
     if (!playback_params) {
 	// use default parameters if none given
 	params          = m_playback_params;
-	params.rate     = fileInfo().rate();
-	params.channels = selectedTracks().count();
+	if (!signalManager().isClosed() && !signalManager().isEmpty()) {
+	    params.rate     = fileInfo().rate();
+	    params.channels = selectedTracks().count();
+	}
     } else {
 	// use given parameters
 	params = *playback_params;
@@ -407,18 +417,17 @@ PlayBackDevice *PlayBackPlugin::openDevice(const QString &name,
     // use default device if no name is given
     if (!device_name.length()) device_name = params.device;
 
-    // create a new device if there isn't one
-    if (!m_device) setMethod(params.method);
-
-    Q_ASSERT(m_device);
-    if (!m_device) {
+    // create a new device
+    device = createDevice(params.method);
+    Q_ASSERT(device);
+    if (!device) {
 	qWarning("PlayBackPlugin::openDevice(): "\
 		"creating device failed.");
 	return 0;
     }
 
     // open and initialize the device
-    QString result = m_device->open(
+    QString result = device->open(
 	params.device,
 	params.rate,
 	params.channels,
@@ -430,8 +439,8 @@ PlayBackDevice *PlayBackPlugin::openDevice(const QString &name,
 	        "opening the device failed.");
 
 	// delete the device if it did not open
-	delete m_device;
-	m_device = 0;
+	delete device;
+	device = 0;
 
 	// show an error message box
 	KMessageBox::error(parentWidget(), result,
@@ -439,7 +448,7 @@ PlayBackDevice *PlayBackPlugin::openDevice(const QString &name,
 	    params.device.section('|',0,0)));
     }
 
-    return m_device;
+    return device;
 }
 
 //***************************************************************************
@@ -557,8 +566,7 @@ void PlayBackPlugin::run(QStringList)
     }
 
     // set up a set of sample reader (streams)
-    MultiTrackReader input;
-    manager().openMultiTrackReader(input, audible_tracks, first, last);
+    MultiTrackReader input(signalManager(), audible_tracks, first, last);
 
     // create a translation matrix for mixing up/down to the desired
     // number of output channels
@@ -693,57 +701,63 @@ void PlayBackPlugin::playbackDone()
 void PlayBackPlugin::testPlayBack()
 {
     const float t_sweep        =   1.0; /* seconds per speaker */
-    const float freq           = 440.0; /* test frequency [Hz] */
+    const double freq          = 440.0; /* test frequency [Hz] */
     const unsigned int periods =     3; /* number of periods to play */
 
     qDebug("PlayBackPlugin::testPlayBack()");
 
-    Q_ASSERT(m_device);
-    if (!m_device) return;
+    Q_ASSERT(m_dialog);
+    if (!m_dialog) return;
+    PlayBackParam playback_params = m_dialog->params();
 
-    if (m_dialog) m_playback_params = m_dialog->params();
-
-    QString open_result = m_device->open(
-	m_playback_params.device,
-	m_playback_params.rate,
-	m_playback_params.channels,
-	m_playback_params.bits_per_sample,
-	m_playback_params.bufbase);
-    if (open_result.length()) {
-	qWarning("open failed: %s", open_result.data());
-	return;
-    }
-    unsigned int tracks = m_playback_params.channels;
+    unsigned int tracks = playback_params.channels;
+    double rate         = playback_params.rate;
     Q_ASSERT(tracks);
-    if (!tracks) return;
+    Q_ASSERT(rate > 1.0);
+    if (!tracks || (rate <= 1.0)) return;
 
-    Arts::Dispatcher *dispatcher = manager().artsDispatcher();
-    Q_ASSERT(dispatcher);
-    if (!dispatcher) close();
-    dispatcher->lock();
+    // settings are valid -> take them
+    m_playback_params = playback_params;
+
+    // create the multi track playback sink
+    Kwave::SampleSink *sink = manager().openMultiTrackPlayback(tracks);
+    Q_ASSERT(sink);
+    if (!sink) return;
 
     float t_period = t_sweep * tracks;
-    unsigned int curve_length =
-	(unsigned int)(t_period * m_playback_params.rate);
+    unsigned int curve_length = (unsigned int)(t_period * rate);
 
+    // create all objects
     Curve curve;
     curve.insert(0.0, 0.0);
-    if (tracks <= 2) {
-	// mono and stereo
+    if (tracks < 2) {
+	// mono
 	curve.insert(0.5, 1.0);
     } else {
 	// all above
-	curve.insert(1.0 / (float)tracks, 1.0);
-	curve.insert(2.0 / (float)tracks, 0.0);
+	curve.insert(0.5 / (float)tracks, 1.0);
+	curve.insert(1.0 / (float)tracks, 0.0);
     }
     curve.insert(1.0, 0.0);
 
-    CurveStreamAdapter curve_adapter = CurveStreamAdapter::_from_base(
-	new CurveStreamAdapter_impl(curve, curve_length)
-    );
+    Kwave::CurveStreamAdapter curve_adapter(curve, curve_length);
 
-    // create all objects
+    Kwave::MultiTrackSource<Kwave::Delay, true> delay(tracks);
+    for (unsigned int i=0; i < tracks; i++) {
+	Q_ASSERT(delay[i]);
+	if (!delay[i]) break;
+	delay[i]->setAttribute(SLOT(setDelay(const QVariant &)),
+	    QVariant(i * t_sweep * rate));
+    }
 
+    Kwave::Osc osc;
+    osc.setAttribute(SLOT(setFrequency(const QVariant &)),
+                     QVariant(rate / freq));
+
+    Kwave::MultiTrackSource<Kwave::Mul, true> mul(tracks);
+
+    // connect everything together...
+    //
     // curve -> delay --.
     //                  |
     //                  v
@@ -752,35 +766,18 @@ void PlayBackPlugin::testPlayBack()
     //                  |
     //            osc --'
 
-    ArtsNativeMultiTrackFilter delay(tracks, "Arts::Synth_CDELAY");
-    for (unsigned int i=0; i < tracks; i++) {
-	std::string command;
-	command = "_set_time";
-	Arts::Object &object(*(delay[i]));
-	Arts::DynamicRequest(object).method(
-	    command).param(i * t_sweep).invoke();
-    }
-
-    ArtsNativeMultiTrackFilter osc(tracks, "Arts::Synth_OSC");
-    osc.setAttribute("frequency", freq);
-
-    ArtsNativeMultiTrackFilter mul(tracks, "Arts::Synth_MUL");
-
-    // create the multi track playback sink
-    ArtsMultiPlaybackSink sink(tracks, m_device);
-
-    // connect them
-    delay.connectInput(curve_adapter, "output", "invalue");
-    mul.connectInput(delay, "outvalue", "invalue1");
-    mul.connectInput(osc,   "outvalue", "invalue2");
-    mul.connectOutput(sink, "sink",     "outvalue");
-
-    // start all
-    curve_adapter.start();
-    delay.start();
-    osc.start();
-    mul.start();
-    sink.start();
+    Kwave::connect(
+	curve_adapter, SIGNAL(output(Kwave::SampleArray &)),
+	delay,         SLOT(input(Kwave::SampleArray &)));
+    Kwave::connect(
+	delay,         SIGNAL(output(Kwave::SampleArray &)),
+	mul,           SLOT(input_a(Kwave::SampleArray &)));
+    Kwave::connect(
+	osc,           SIGNAL(output(Kwave::SampleArray &)),
+	mul,           SLOT(input_b(Kwave::SampleArray &)));
+    Kwave::connect(
+	mul,           SIGNAL(output(Kwave::SampleArray &)),
+	*sink,         SLOT(input(Kwave::SampleArray &)));
 
     // show a progress dialog
     QProgressDialog *progress = 0;
@@ -804,8 +801,13 @@ void PlayBackPlugin::testPlayBack()
     QTime time;
     time.start();
     int t_max = periods * (int)t_period * 1000;
-    while ((time.elapsed() < t_max) && (!sink.done())) {
-	sink.goOn();
+    while ((time.elapsed() < t_max) /*&& (!sink.done())*/) {
+
+	osc.goOn();
+	curve_adapter.goOn();
+	delay.goOn();
+	mul.goOn();
+
 	if (progress) {
 	    progress->setProgress((100 * time.elapsed()) / t_max);
 	    if (progress->wasCancelled()) break;
@@ -813,17 +815,7 @@ void PlayBackPlugin::testPlayBack()
     }
 
     if (progress) delete progress;
-    progress = 0;
-
-    // shutdown
-    sink.stop();
-    mul.stop();
-    osc.stop();
-    delay.stop();
-    curve_adapter.stop();
-    dispatcher->unlock();
-
-    m_device->close();
+    if (sink)     delete sink;
 }
 
 //***************************************************************************
