@@ -60,7 +60,7 @@ RecordPlugin::RecordPlugin(const PluginContext &context)
     :KwavePlugin(context), m_method(), m_device_name(), m_controller(),
      m_state(REC_EMPTY), m_device(0),
      m_dialog(0), m_thread(0), m_decoder(0), m_prerecording_queue(),
-     m_writers(), m_buffers_recorded(0), m_inhibit_count(0),
+     m_writers(0), m_buffers_recorded(0), m_inhibit_count(0),
      m_trigger_value()
 {
     m_prerecording_queue.setAutoDelete(true);
@@ -744,7 +744,7 @@ void RecordPlugin::resetRecording(bool &accepted)
     accepted = topwidget.closeFile();
     if (!accepted) return;
 
-    m_writers.resize(0);
+    if (m_writers) m_writers->clear();
     m_buffers_recorded = 0;
 
     m_controller.setEmpty(true);
@@ -813,11 +813,9 @@ void RecordPlugin::setupRecordThread()
     if (params.pre_record_enabled) {
 	// prepare a queue for each track
 	m_prerecording_queue.resize(params.tracks);
-	unsigned int fifo_depth = (unsigned int)ceil((
-	    params.pre_record_time * params.sample_rate));
 
 	for (unsigned int track=0; track < params.tracks; ++track) {
-	    SampleFIFO *fifo = new SampleFIFO(fifo_depth);
+	    SampleFIFO *fifo = new SampleFIFO();
 	    m_prerecording_queue.insert(track, fifo);
 	    Q_ASSERT(fifo);
 	    if (!fifo) {
@@ -864,7 +862,8 @@ void RecordPlugin::startRecording()
 	 * if tracks or sample rate has changed
 	 * -> start over with a new signal and new settings
 	 */
-	if ((m_writers.count() != tracks) ||
+	if ((!m_writers) ||
+	    (m_writers->tracks() != tracks) ||
 	    (fileInfo().rate() != rate))
 	{
 	    // create a new and empty signal
@@ -876,9 +875,11 @@ void RecordPlugin::startRecording()
 	    signalManager().disableUndo();
 
 	    // create a sink for our audio data
-	    manager().openMultiTrackWriter(m_writers, Append);
-	    Q_ASSERT(m_writers.count() == tracks);
-	    if (m_writers.count() != tracks) {
+	    if (m_writers) delete m_writers;
+	    m_writers = new MultiTrackWriter(signalManager(), Append);
+	    Q_ASSERT(m_writers);
+	    Q_ASSERT((m_writers) && (m_writers->tracks() == tracks));
+	    if ((!m_writers) || (m_writers->tracks() != tracks)) {
 		KMessageBox::sorry(m_dialog, i18n("Out of memory"));
 		return;
 	    }
@@ -890,7 +891,6 @@ void RecordPlugin::startRecording()
 	fileInfo().setRate(rate);
 	fileInfo().setBits(bits);
 	fileInfo().setTracks(tracks);
-//	fileInfo().setLength(m_writers.last());
 	fileInfo().set(INF_MIMETYPE, "audio/vnd.wave");
 	fileInfo().set(INF_SAMPLE_FORMAT,
 	    m_dialog->params().sample_format.toInt());
@@ -939,9 +939,9 @@ void RecordPlugin::recordStopped(int reason)
     }
     KMessageBox::error(m_dialog, description);
 
-    m_writers.flush();
+    if (m_writers) m_writers->flush();
     qDebug("RecordPlugin::recordStopped(): wrote %u samples",
-           m_writers.last());
+           (m_writers) ? m_writers->last() : 0);
 
     // flush away all prerecording buffers
     m_prerecording_queue.clear();
@@ -1043,7 +1043,8 @@ bool RecordPlugin::checkTrigger(unsigned int track,
     Q_ASSERT(m_dialog);
     if (!m_dialog) return false;
     if (!buffer.size()) return false;
-    if (m_trigger_value.size() != m_writers.count()) return false;
+    if (!m_writers) return false;
+    if (m_trigger_value.size() != m_writers->tracks()) return false;
 
     // shortcut if no trigger has been set
     if (!m_dialog->params().record_trigger_enabled) return true;
@@ -1141,8 +1142,10 @@ void RecordPlugin::flushPrerecordingQueue()
     const unsigned int tracks = params.tracks;
     Q_ASSERT(tracks);
     if (!tracks) return;
-    Q_ASSERT(tracks == m_writers.count());
-    if (!tracks || (tracks != m_writers.count())) return;
+    Q_ASSERT(m_writers);
+    if (!m_writers) return;
+    Q_ASSERT(tracks == m_writers->tracks());
+    if (!tracks || (tracks != m_writers->tracks())) return;
 
     for (unsigned int track=0; track < tracks; ++track) {
 	SampleFIFO *fifo = m_prerecording_queue.at(track);
@@ -1152,15 +1155,22 @@ void RecordPlugin::flushPrerecordingQueue()
 	if (!fifo->length()) continue;
 
 	// push all buffers to the writer, starting at the tail
-	SampleWriter *writer = m_writers[track];
+	SampleWriter *writer = (*m_writers)[track];
 	Q_ASSERT(writer);
 	if (writer) {
-	    fifo->align();
-	    *writer << fifo->data();
+	    Kwave::SampleArray buffer(writer->blockSize());
+	    unsigned int rest = fifo->length();
+	    while (rest) {
+		unsigned int read = fifo->get(buffer);
+		if (read < 1) break;
+		writer->flush(buffer, read);
+		rest -= read;
+	    }
+	} else {
+	    // fallback: discard the FIFO content
+	    fifo->flush();
 	}
-
-	// discard the FIFO and it's content
-	fifo->resize(0);
+	Q_ASSERT(fifo->length() == 0);
     }
 
     // the queues are no longer needed
@@ -1178,7 +1188,8 @@ void RecordPlugin::processBuffer(QByteArray buffer)
 //     qDebug("RecordPlugin::processBuffer()");
     Q_ASSERT(m_dialog);
     Q_ASSERT(m_thread);
-    if (!m_dialog || !m_thread || !m_decoder) return;
+    Q_ASSERT(m_writers);
+    if (!m_dialog || !m_thread || !m_decoder || !m_writers) return;
 
     // we received a buffer -> update the progress bar
     updateBufferProgressBar();
@@ -1199,7 +1210,7 @@ void RecordPlugin::processBuffer(QByteArray buffer)
 
     // check for reached recording time limit if enabled
     if (params.record_time_limited) {
-	const unsigned int already_recorded = m_writers.last()+1;
+	const unsigned int already_recorded = m_writers->last()+1;
 	const unsigned int limit = (unsigned int)rint(
 	    params.record_time * params.sample_rate);
 	if (already_recorded + samples >= limit) {
@@ -1281,10 +1292,10 @@ void RecordPlugin::processBuffer(QByteArray buffer)
 		break;
 	    case REC_RECORDING: {
 		// put the decoded track data into the buffer
-		Q_ASSERT(tracks == m_writers.count());
-		if (!tracks || (tracks != m_writers.count())) break;
+		Q_ASSERT(tracks == m_writers->tracks());
+		if (!tracks || (tracks != m_writers->tracks())) break;
 
-		SampleWriter *writer = m_writers[track];
+		SampleWriter *writer = (*m_writers)[track];
 		Q_ASSERT(writer);
 		if (writer) (*writer) << decoded;
 		m_controller.setEmpty(false);
@@ -1295,7 +1306,7 @@ void RecordPlugin::processBuffer(QByteArray buffer)
     }
 
     // update the number of recorded samples
-    emit sigRecordedSamples(m_writers.last()+1);
+    emit sigRecordedSamples(m_writers->last()+1);
 
     // if this was the last received buffer, change state
     if (recording_done && (m_state != REC_DONE) && (m_state != REC_EMPTY)) {
