@@ -257,8 +257,7 @@ void SonagramPlugin::run(QStringList /* params */)
     Q_ASSERT(m_spx_insert_stripe);
     if (!m_spx_insert_stripe) return;
 
-    MultiTrackReader source;
-    manager().openMultiTrackReader(source, selectedTracks(),
+    MultiTrackReader source(signalManager(), selectedTracks(),
 	m_first_sample, m_last_sample);
 //    qDebug("SonagramPlugin::run(), first=%u, last=%u",m_first_sample,m_last_sample);
 
@@ -362,7 +361,7 @@ void SonagramPlugin::calculateStripe(MultiTrackReader &source,
     for (unsigned int j = 0; j < points; j++) {
 	double value = 0.0;
 	if (!(source.eof())) {
-	    unsigned int count = source.count();
+	    unsigned int count = source.tracks();
 	    unsigned int t;
 	    for (t=0; t < count; t++) {
 		sample_t s = 0;
